==> aws-cdk-lib-2.0.0-rc.14-sources.jar: software/amazon/awscdk/services/codepipeline/StageProps.java <==
package software.amazon.awscdk.services.codepipeline;

/**
 * (experimental) Construction properties of a Pipeline Stage.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-07-21T10:24:10.365Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_codepipeline.StageProps")
@software.amazon.jsii.Jsii.Proxy(StageProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface StageProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) The physical, human-readable name to assign to this Pipeline Stage.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getStageName();

    /**
     * (experimental) The list of Actions to create this Stage with.
     * <p>
     * You can always add more Actions later by calling {&#64;link IStage#addAction}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.codepipeline.IAction> getActions() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link StageProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link StageProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<StageProps> {
        private java.lang.String stageName;
        private java.util.List<software.amazon.awscdk.services.codepipeline.IAction> actions;

        /**
         * Sets the value of {@link StageProps#getStageName}
         * @param stageName The physical, human-readable name to assign to this Pipeline Stage. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder stageName(java.lang.String stageName) {
            this.stageName = stageName;
            return this;
        }

        /**
         * Sets the value of {@link StageProps#getActions}
         * @param actions The list of Actions to create this Stage with.
         *                You can always add more Actions later by calling {&#64;link IStage#addAction}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder actions(java.util.List<? extends software.amazon.awscdk.services.codepipeline.IAction> actions) {
            this.actions = (java.util.List<software.amazon.awscdk.services.codepipeline.IAction>)actions;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link StageProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public StageProps build() {
            return new Jsii$Proxy(stageName, actions);
        }
    }

    /**
     * An implementation for {@link StageProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements StageProps {
        private final java.lang.String stageName;
        private final java.util.List<software.amazon.awscdk.services.codepipeline.IAction> actions;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.stageName = software.amazon.jsii.Kernel.get(this, "stageName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.actions = software.amazon.jsii.Kernel.get(this, "actions", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codepipeline.IAction.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final java.lang.String stageName, final java.util.List<? extends software.amazon.awscdk.services.codepipeline.IAction> actions) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.stageName = java.util.Objects.requireNonNull(stageName, "stageName is required");
            this.actions = (java.util.List<software.amazon.awscdk.services.codepipeline.IAction>)actions;
        }

        @Override
        public final java.lang.String getStageName() {
            return this.stageName;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.codepipeline.IAction> getActions() {
            return this.actions;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("stageName", om.valueToTree(this.getStageName()));
            if (this.getActions() != null) {
                data.set("actions", om.valueToTree(this.getActions()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_codepipeline.StageProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            StageProps.Jsii$Proxy that = (StageProps.Jsii$Proxy) o;

            if (!stageName.equals(that.stageName)) return false;
            return this.actions != null ? this.actions.equals(that.actions) : that.actions == null;
        }

        @Override
        public final int hashCode() {
            int result = this.stageName.hashCode();
            result = 31 * result + (this.actions != null ? this.actions.hashCode() : 0);
            return result;
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/codepipeline/StageProps.java <==
package software.amazon.awscdk.services.codepipeline;

/**
 * Construction properties of a Pipeline Stage.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.codepipeline.*;
 * Action action;
 * StageProps stageProps = StageProps.builder()
 *         .stageName("stageName")
 *         // the properties below are optional
 *         .actions(List.of(action))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:08.394Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_codepipeline.StageProps")
@software.amazon.jsii.Jsii.Proxy(StageProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface StageProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The physical, human-readable name to assign to this Pipeline Stage.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getStageName();

    /**
     * The list of Actions to create this Stage with.
     * <p>
     * You can always add more Actions later by calling {&#64;link IStage#addAction}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.codepipeline.IAction> getActions() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link StageProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link StageProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<StageProps> {
        java.lang.String stageName;
        java.util.List<software.amazon.awscdk.services.codepipeline.IAction> actions;

        /**
         * Sets the value of {@link StageProps#getStageName}
         * @param stageName The physical, human-readable name to assign to this Pipeline Stage. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder stageName(java.lang.String stageName) {
            this.stageName = stageName;
            return this;
        }

        /**
         * Sets the value of {@link StageProps#getActions}
         * @param actions The list of Actions to create this Stage with.
         *                You can always add more Actions later by calling {&#64;link IStage#addAction}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder actions(java.util.List<? extends software.amazon.awscdk.services.codepipeline.IAction> actions) {
            this.actions = (java.util.List<software.amazon.awscdk.services.codepipeline.IAction>)actions;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link StageProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public StageProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link StageProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements StageProps {
        private final java.lang.String stageName;
        private final java.util.List<software.amazon.awscdk.services.codepipeline.IAction> actions;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.stageName = software.amazon.jsii.Kernel.get(this, "stageName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.actions = software.amazon.jsii.Kernel.get(this, "actions", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codepipeline.IAction.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.stageName = java.util.Objects.requireNonNull(builder.stageName, "stageName is required");
            this.actions = (java.util.List<software.amazon.awscdk.services.codepipeline.IAction>)builder.actions;
        }

        @Override
        public final java.lang.String getStageName() {
            return this.stageName;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.codepipeline.IAction> getActions() {
            return this.actions;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("stageName", om.valueToTree(this.getStageName()));
            if (this.getActions() != null) {
                data.set("actions", om.valueToTree(this.getActions()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_codepipeline.StageProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            StageProps.Jsii$Proxy that = (StageProps.Jsii$Proxy) o;

            if (!stageName.equals(that.stageName)) return false;
            return this.actions != null ? this.actions.equals(that.actions) : that.actions == null;
        }

        @Override
        public final int hashCode() {
            int result = this.stageName.hashCode();
            result = 31 * result + (this.actions != null ? this.actions.hashCode() : 0);
            return result;
        }
    }
}
